@@ -17,7 +17,7 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.46.0"
+version = "1.47.1"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -27,7 +27,7 @@ arch_native = pmb.parse.arch.alpine_native()
 # Update this frequently to prevent a MITM attack with an outdated version
 # (which may contain a vulnerable apk/openssl, and allows an attacker to
 # exploit the system!)
-apk_tools_min_version = {"edge": "2.12.9-r6",
+apk_tools_min_version = {"edge": "2.12.9-r7",
                          "v3.16": "2.12.9-r3",
                          "v3.15": "2.12.7-r3",
                          "v3.14": "2.12.7-r0",
@@ -329,8 +329,8 @@ necessary_kconfig_options = {
     }
 }
 
-# Necessary anbox/waydroid kernel config options (android app support)
-necessary_kconfig_options_anbox = {
+# Necessary waydroid kernel config options (android app support)
+necessary_kconfig_options_waydroid = {
     ">=0.0.0": {  # all versions
         "all": {  # all arches
             "SQUASHFS": True,
@@ -354,12 +354,12 @@ necessary_kconfig_options_anbox = {
     },
     ">=3.5": {
         "all": {
-            "CROSS_MEMORY_ATTACH": True,  # required by Waydroid
+            "CROSS_MEMORY_ATTACH": True,
         }
     },
     ">=4.20.0": {
         "all": {
-            "PSI": True,  # required by userspace OOM killer in Waydroid
+            "PSI": True,  # required by userspace OOM killer
             "PSI_DEFAULT_DISABLED": False,
         }
     },
@@ -370,26 +370,6 @@ necessary_kconfig_options_anbox = {
     }
 }
 
-# Necessary apparmor kernel config options (mandatory access control)
-# LSM: the value that "config LSM" sets in security/Kconfig, if
-# DEFAULT_SECURITY_APPARMOR is set (and other DEFAULT_SECURITY_* are unset).
-necessary_kconfig_options_apparmor = {
-    ">=0.0.0": {  # all versions
-        "all": {  # all arches
-            "AUDIT": True,
-            "DEFAULT_SECURITY_APPARMOR": True,
-            "LSM": "landlock,lockdown,yama,loadpin,safesetid,integrity,"
-                   "apparmor,selinux,smack,tomoyo,bpf",
-            "SECURITY_APPARMOR": True,
-        },
-    },
-    "<5.1": {
-        "all": {
-            "SECURITY_APPARMOR_BOOTPARAM_VALUE": True,
-        },
-    },
-}
-
 # Necessary iwd kernel config options (inet wireless daemon)
 # Obtained from 'grep ADD_MISSING src/main.c' in iwd.git
 necessary_kconfig_options_iwd = {
@@ -470,7 +450,7 @@ necessary_kconfig_options_containers = {
             "CPUSETS": True,
             "KEYS": True,
             "VETH": True,
-            "BRIDGE": True,  # (also needed for anbox)
+            "BRIDGE": True,  # (also needed for waydroid)
             "BRIDGE_NETFILTER": True,
             "IP_NF_FILTER": True,
             "IP_NF_TARGET_MASQUERADE": True,
@@ -519,7 +499,7 @@ necessary_kconfig_options_containers = {
             "DM_THIN_PROVISIONING": True,  # Storage Drivers
         },
         "x86 x86_64": {  # only for x86, x86_64 (and sparc64, ia64)
-            "CONFIG_HUGETLB_PAGE": True,
+            "HUGETLB_PAGE": True,
             "CGROUP_HUGETLB": True,  # Optional section
         }
     },
@@ -537,7 +517,7 @@ necessary_kconfig_options_containers = {
     },
     ">=3.9": {
         "all": {  # all arches
-            "BRIDGE_VLAN_FILTERING": True,  # Network Drivers (also for anbox)
+            "BRIDGE_VLAN_FILTERING": True,  # Network Drivers (also for waydroid)
             "MACVLAN": True,  # Network Drivers
         }
     },
@@ -613,6 +593,7 @@ apkbuild_package_attributes = {
     "provides": {"array": True},
     "provider_priority": {"int": True},
     "install": {"array": True},
+    "triggers": {"array": True},
 
     # UI meta-packages can specify apps in "_pmb_recommends" to be explicitly
     # installed by default, and not implicitly as dependency of the UI meta-
@@ -668,13 +649,17 @@ apkbuild_attributes = {
     # git commit
     "_commit": {},
     "source": {"array": True},
+
+    # gcc
+    "_pkgbase": {},
+    "_pkgsnap": {}
 }
 
 # Reference: https://postmarketos.org/apkbuild-options
 apkbuild_custom_valid_options = [
     "!pmb:crossdirect",
     "!pmb:kconfig-check",
-    "pmb:kconfigcheck-anbox",
+    "pmb:kconfigcheck-waydroid",
     "pmb:kconfigcheck-containers",
     "pmb:kconfigcheck-nftables",
     "pmb:cross-native",
