@@ -464,10 +464,8 @@ def arguments_kconfig(subparser):
     check.add_argument("--arch", choices=arch_choices, dest="arch")
     check.add_argument("--file", action="store_true", help="check a file"
                        " directly instead of a config in a package")
-    check.add_argument("--anbox", action="store_true", help="check"
-                       " options needed for anbox too")
-    check.add_argument("--apparmor", action="store_true", help="check"
-                       " options needed for apparmor too")
+    check.add_argument("--waydroid", action="store_true", help="check"
+                       " options needed for waydroid too")
     check.add_argument("--iwd", action="store_true", help="check"
                        " options needed for iwd too")
     check.add_argument("--nftables", action="store_true", help="check"
@@ -478,6 +476,9 @@ def arguments_kconfig(subparser):
                        " options needed for zram support too")
     check.add_argument("--netboot", action="store_true", help="check"
                        " options needed for netbooting too")
+    check.add_argument("--community", action="store_true", help="check"
+                       " options needed for various features, required for"
+                       " community/main devices")
     check.add_argument("--uefi", action="store_true", help="check"
                        " options needed for uefi too")
     add_kernel_arg(check)
